@@ -44,7 +44,6 @@
 #include <gdbus.h>
 
 #include "logging.h"
-#include "textfile.h"
 #include "uinput.h"
 
 #include "device.h"
@@ -53,7 +52,7 @@
 #include "fakehid.h"
 #include "glib-helper.h"
 
-#define INPUT_DEVICE_INTERFACE "org.bluez.input.Device"
+#define INPUT_DEVICE_INTERFACE "org.bluez.Input"
 
 #define BUF_SIZE		16
 
@@ -1002,13 +1001,6 @@ int input_device_unregister(const char *path, const char *uuid)
 	return 0;
 }
 
-gboolean input_device_is_registered(bdaddr_t *src, bdaddr_t *dst)
-{
-	struct input_device *idev = find_device(src, dst);
-
-	return idev ? TRUE : FALSE;
-}
-
 int input_device_set_channel(const bdaddr_t *src, const bdaddr_t *dst, int psm, int nsk)
 {
 	struct input_device *idev = find_device(src, dst);
